@@ -79,7 +79,10 @@ def sql(key):
         'KAIBusinessId': {'sql':"SELECT id From KAIBusiness ;",'database': 'AnyRobot'},
         'graphName': {'sql':"SELECT graph_name From graph ;",'database': 'AnyRobot'},
         'ScheduleTaskId': {'sql':"SELECT id From ScheduleTask ;",'database': 'AnyRobot'},
-        'ScheduleTaskId1': {'sql':"SELECT id From ScheduleTask ;",'database': 'AnyRobot'}
+        'ScheduleTaskId1': {'sql':"SELECT id From ScheduleTask ;",'database': 'AnyRobot'},
+        'UserId': {'sql':"SELECT userId From User ;",'database': 'AnyRobot'},
+        'UserId2': {'sql':"SELECT userId From User ;",'database': 'AnyRobot'},
+        'alertLogId': {'sql':"SELECT alert_scenario_rule_id From RuleEngineAlertLog ;",'database': 'AnyRobot'}
     }
 
     if switcher.get(key) is not None:
