@@ -3,6 +3,7 @@ from aishu.datafaker.profession.entity import name, switch, ip, timestamp, ml, k
 from aishu.datafaker.profession.entity import zx
 from aishu.datafaker.profession.entity.ParaDateFiled import ParaDateFiledServer
 from aishu.datafaker.profession.entity.RetrievesAssociated import ParaDateAnyRobotServer
+from aishu.datafaker.profession.entity import CreateTestPort
 
 def filed(key,inquire=[]):
     """
@@ -74,7 +75,9 @@ def filed(key,inquire=[]):
         'InspectionTaskID': zx.search().createInspectionTaskID,
         'ExportFileID': zx.search().createExportFileID,
         'RepeatInspectionName': zx.search().getRepeatInspectionName,
-        'agentDeployIp':ip.date().getAentHostIp
+        'agentDeployIp':ip.date().getAentHostIp,
+        'http_port':CreateTestPort.Port().httpport,
+        'syslog_port':CreateTestPort.Port().syslogPort
     }
 
     switcher = SERVICE_KPI_
